@@ -1,6 +1,7 @@
 # coding=utf-8
 from __future__ import absolute_import, print_function
 
+import inspect
 from unittest import mock
 
 from suanpan import error
@@ -10,39 +11,35 @@ from suanpan.app import MessageHandler
 
 
 class BaseApp(HasName):
-    def __init__(self):
-        self._handlerClass = None
-
     def __call__(self, *args, **kwargs):
         raise NotImplementedError("Method not implemented!")
 
     def start(self, *args, **kwargs):  # pylint: disable=unused-argument
         logger.info(f"Suanpan component {self.name} start...")
-        if self._handlerClass:
-            try:
-                handler = self._handlerClass()
-                for arg in handler.inputs:
-                    self.input(arg)
-                for arg in handler.outputs:
-                    self.output(arg)
-                for arg in handler.params:
-                    self.param(arg)
-
-                handler.init_params(*args, **kwargs)
-                self.beforeInit(handler.beforeInit)
-                self.afterInit(handler.afterInit)
-                self.beforeCall(handler.beforeCall)
-                self.afterCall(handler.afterCall)
-
-                self(handler.run)
-                handler.initialize()
-            except Exception as e:
-                raise error.AppError(f"handler class {self._handlerClass} init failed: {e}")
 
     def use(self, handlerClass):
-        if not issubclass(handlerClass, MessageHandler):
+        if inspect.isclass(handlerClass) and issubclass(handlerClass, MessageHandler):
+            handler = handlerClass()
+        elif isinstance(handlerClass, MessageHandler):
+            handler = handlerClass
+        else:
             raise error.AppError(f"can't use {handlerClass}")
-        self._handlerClass = handlerClass
+
+        for arg in handler.inputs:
+            self.input(arg)
+        for arg in handler.outputs:
+            self.output(arg)
+        for arg in handler.params:
+            self.param(arg)
+
+        handler.init_params()
+        self.beforeInit(handler.beforeInit)
+        self.afterInit(handler.afterInit)
+        self.beforeCall(handler.beforeCall)
+        self.afterCall(handler.afterCall)
+
+        self(handler.run)
+        handler.initialize()
 
     @property
     def trigger(self):
